@@ -15,21 +15,6 @@ namespace vcpkg
         AUTO_SELECTED
     };
 
-    enum class InstallPlanType
-    {
-        UNKNOWN,
-        BUILD_AND_INSTALL,
-        ALREADY_INSTALLED,
-        EXCLUDED
-    };
-
-    enum class ExportPlanType
-    {
-        UNKNOWN,
-        NOT_BUILT,
-        ALREADY_BUILT
-    };
-
     struct BasicAction;
     struct PackageAction;
     struct InstallPlanAction;
