@@ -1084,6 +1084,31 @@ namespace vcpkg::Json
                 return ParsedJson{std::move(val), parser.style()};
             }
 
+            static Optional<ParsedJson> parse(DiagnosticContext& context, StringView json, StringView origin)
+            {
+                StatsTimer t(g_json_parsing_stats);
+
+                json.remove_bom();
+
+                auto parser = Parser(json, origin, {1, 1});
+
+                auto val = parser.parse_value();
+
+                parser.skip_whitespace();
+                if (!parser.at_eof())
+                {
+                    parser.add_error(msg::format(msgUnexpectedEOFExpectedChar));
+                }
+
+                if (parser.messages().any_errors())
+                {
+                    std::move(parser).messages().report(context);
+                    return nullopt;
+                }
+
+                return ParsedJson{std::move(val), parser.style()};
+            }
+
             JsonStyle style() const noexcept { return style_; }
 
         private:
@@ -1170,6 +1195,11 @@ namespace vcpkg::Json
 
     ExpectedL<ParsedJson> parse(StringView json, StringView origin) { return Parser::parse(json, origin); }
 
+    Optional<ParsedJson> parse(DiagnosticContext& context, StringView text, StringView origin)
+    {
+        return Parser::parse(context, text, origin);
+    }
+
     ExpectedL<Json::Object> parse_object(StringView text, StringView origin)
     {
         return parse(text, origin).then([&](ParsedJson&& mabeValueIsh) -> ExpectedL<Json::Object> {
@@ -1179,7 +1209,22 @@ namespace vcpkg::Json
                 return std::move(*as_object);
             }
 
-            return msg::format(msgJsonErrorMustBeAnObject, msg::path = origin);
+            return LocalizedString::from_raw(
+                DiagnosticLine{DiagKind::Error, origin, msg::format(msgExpectedAnObject)}.to_string());
+        });
+    }
+
+    Optional<Json::Object> parse_object(DiagnosticContext& context, StringView text, StringView origin)
+    {
+        return parse(context, text, origin).then([&](ParsedJson&& mabeValueIsh) -> Optional<Json::Object> {
+            auto& asValue = mabeValueIsh.value;
+            if (auto as_object = asValue.maybe_object())
+            {
+                return std::move(*as_object);
+            }
+
+            context.report(DiagnosticLine{DiagKind::Error, origin, msg::format(msgExpectedAnObject)});
+            return nullopt;
         });
     }
     // } auto parse()
