@@ -18,6 +18,6 @@ namespace vcpkg
         local_variables.emplace_back("_VCPKG_INSTALLED_DIR", paths.installed().root());
         local_variables.emplace_back("DOWNLOADS", paths.downloads);
         local_variables.emplace_back("VCPKG_MANIFEST_INSTALL", "OFF");
-        return make_basic_cmake_cmd(paths.get_tool_exe(Tools::CMAKE, out_sink), cmake_script, local_variables);
+        return make_basic_cmake_cmd(paths.get_tool_path_required(Tools::CMAKE), cmake_script, local_variables);
     }
 }
