@@ -359,7 +359,7 @@ namespace vcpkg
 #if defined(WIN32)
         auto& fs = paths.get_filesystem();
 
-        const Path& nuget_exe = paths.get_tool_exe(Tools::NUGET, out_sink);
+        const Path& nuget_exe = paths.get_tool_path_required(Tools::NUGET);
 
         const auto tmp_dir = fs.create_or_get_temp_directory(VCPKG_LINE_INFO);
         const auto targets_file_path = tmp_dir / "vcpkg.nuget.targets";
@@ -418,7 +418,7 @@ namespace vcpkg
         static constexpr StringLiteral TITLE = "PowerShell Tab-Completion";
         const auto script_path = paths.scripts / "addPoshVcpkgToPowershellProfile.ps1";
 
-        const auto& ps = paths.get_tool_exe("powershell-core", out_sink);
+        const auto& ps = paths.get_tool_path_required("powershell-core");
         const auto rc = cmd_execute(Command{ps}
                                         .string_arg("-NoProfile")
                                         .string_arg("-ExecutionPolicy")
